@@ -90,6 +90,7 @@ INSTALLED_APPS = (
 
 
 MIDDLEWARE = [
+    'allauth.account.middleware.AccountMiddleware',
     'django.contrib.sessions.middleware.SessionMiddleware',
     # NOTE: Do not include DebugToolbarMiddleware in any production site.
     'debug_toolbar.middleware.DebugToolbarMiddleware',
@@ -121,7 +122,6 @@ TEMPLATES = [
                 'django.template.context_processors.media',
                 'django.template.context_processors.static',
                 'django.template.context_processors.tz',
-                'django.template.context_processors.csrf',
                 'django.template.context_processors.request',
                 'django.contrib.auth.context_processors.auth',
                 'django.contrib.messages.context_processors.messages',
