@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2012-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2012-2023 by the Free Software Foundation, Inc.
 #
 # This file is part of Postorius.
 #
@@ -30,52 +30,57 @@ from postorius.forms.fields import SiteModelChoiceField
 def _get_web_host_help():
     # Using a function is necessary, otherwise reverse() will be called before
     # URLConfs are loaded.
-    return (_(
+    return _(
         'The domain from which you want the web UI to be served from. '
         'This can be same or different from the Mail Host. '
         'You can edit the list of available web hosts <a href="%s">here</a>.'
-    ) % reverse("admin:sites_site_changelist"))
+    ) % reverse('admin:sites_site_changelist')
 
 
 class DomainForm(forms.Form):
     """
     Form to add a domain.
     """
+
     mail_host = forms.CharField(
         label=_('Mail Host'),
-        error_messages={'required': _('Please enter a domain name'),
-                        'invalid': _('Please enter a valid domain name.')},
+        error_messages={
+            'required': _('Please enter a domain name'),
+            'invalid': _('Please enter a valid domain name.'),
+        },
         required=True,
         help_text=_(
             'The domain for your mailing lists. For example when you want '
-            'lists like testing@example.com, enter example.com here.'),
-        )
-    description = forms.CharField(
-        label=_('Description'),
-        required=False)
+            'lists like testing@example.com, enter example.com here.'
+        ),
+    )
+    description = forms.CharField(label=_('Description'), required=False)
     alias_domain = forms.CharField(
         label=_('Alias Domain'),
         error_messages={
-            'invalid': _('Please enter a valid domain name or nothing.')},
+            'invalid': _('Please enter a valid domain name or nothing.')
+        },
         required=False,
         help_text=_('Normally empty.  Used only for unusual Postfix configs.'),
-        )
+    )
     site = SiteModelChoiceField(
         label=_('Web Host'),
-        error_messages={'required': _('Please enter a domain name'),
-                        'invalid': _('Please enter a valid domain name.')},
+        error_messages={
+            'required': _('Please enter a domain name'),
+            'invalid': _('Please enter a valid domain name.'),
+        },
         required=True,
-        queryset=Site.objects.order_by("name").all(),
+        queryset=Site.objects.order_by('name').all(),
         initial=lambda: Site.objects.get_current(),
         help_text=_get_web_host_help,
-        )
+    )
 
     def clean_mail_host(self):
         mail_host = self.cleaned_data['mail_host']
         try:
             validate_email('mail@' + mail_host)
         except ValidationError:
-            raise forms.ValidationError(_("Please enter a valid domain name"))
+            raise forms.ValidationError(_('Please enter a valid domain name'))
         return mail_host
 
     def clean_alias_domain(self):
@@ -85,7 +90,8 @@ class DomainForm(forms.Form):
                 validate_email('mail@' + alias_domain)
             except ValidationError:
                 raise forms.ValidationError(
-                    _("Please enter a valid domain name or nothing."))
+                    _('Please enter a valid domain name or nothing.')
+                )
         return alias_domain
 
 
@@ -94,11 +100,13 @@ class DomainEditForm(DomainForm):
     Form to edit domains
     separte from the DomainForm, so that the mail_host can't be changed.
     """
+
     mail_host = None
 
 
 class DomainOwnerForm(forms.Form):
     """Form to add a owner for a domain."""
+
     email = forms.EmailField(
         label=_("Owner's Email"),
         required=True,
